# LEECHCRAFT_INCLUDE_DIR
# LEECHCRAFT_LIBRARIES
# LEECHCRAFT_FOUND

FIND_PATH(LEECHCRAFT_INCLUDE_DIR NAMES leechcraft/config.h PATH ENV)
IF (LEECHCRAFT_INCLUDE_DIR)
	SET (LEECHCRAFT_INCLUDE_DIR "${LEECHCRAFT_INCLUDE_DIR}/leechcraft")
ENDIF (LEECHCRAFT_INCLUDE_DIR)
FIND_LIBRARY(_LEECHCRAFT_UTIL NAMES lcutil)
FIND_LIBRARY(_LEECHCRAFT_XSD NAMES xmlsettingsdialog)
SET (LEECHCRAFT_LIBRARIES ${_LEECHCRAFT_UTIL} ${_LEECHCRAFT_XSD})
SET (LEECHCRAFT_USE_FILE "${CMAKE_MODULE_PATH}/UseLeechCraft.cmake")

IF(LEECHCRAFT_INCLUDE_DIR AND _LEECHCRAFT_UTIL AND _LEECHCRAFT_XSD)
	SET(LEECHCRAFT_FOUND 1)
ENDIF()

IF(LEECHCRAFT_FOUND)
	MESSAGE(STATUS "Found LeechCraft libraries at ${LEECHCRAFT_LIBRARIES}")
	MESSAGE(STATUS "Found LeechCraft headers at ${LEECHCRAFT_INCLUDE_DIR}")
ELSE()
	IF(LEECHCRAFT_FIND_REQUIRED)
		MESSAGE(FATAL_ERROR "Could NOT find required LeechCraft library, aborting")
	ELSE()
		MESSAGE(STATUS "Could NOT find LeechCraft")
	ENDIF()
ENDIF()

IF (NOT CMAKE_VERSION VERSION_LESS 2.8.6)
	MESSAGE (STATUS "CMake 2.8.6 or greater found, enabling automoc...")
	SET (CMAKE_AUTOMOC TRUE)
	SET (LC_NO_MOC TRUE)
ENDIF (NOT CMAKE_VERSION VERSION_LESS 2.8.6)

FUNCTION (CreateTrVars PlugName Langs TranVar CompiledTranVar)
	STRING (LENGTH "${PlugName}" _pnameLength)
	SET (_basename "leechcraft")
	IF (_pnameLength)
		SET (_basename "${_basename}_${PlugName}")
	ENDIF (_pnameLength)
	FOREACH (_LANG ${Langs})
		SET (_tran ${_tran} ${_basename}_${_LANG}.ts)
		SET (_ctran ${_ctran} ${CMAKE_CURRENT_SOURCE_DIR}/${_basename}_${_LANG}.qm)
	ENDFOREACH (_LANG)
	SET (${TranVar} ${_tran} PARENT_SCOPE)
	SET (${CompiledTranVar} ${_ctran} PARENT_SCOPE)
ENDFUNCTION (CreateTrVars)

FUNCTION (CreateTrs PlugName Langs CompiledTranVar)
	STRING (LENGTH "${PlugName}" _pnameLength)
	SET (_basename "leechcraft")
	IF (_pnameLength)
		SET (_basename "${_basename}_${PlugName}")
	ENDIF (_pnameLength)
	FOREACH (_LANG ${Langs})
		SET (_tran ${_tran} ${_basename}_${_LANG}.ts)
		SET (_ctran ${_ctran} ${CMAKE_CURRENT_SOURCE_DIR}/${_basename}_${_LANG}.qm)
	ENDFOREACH (_LANG)
	SET (${CompiledTranVar} ${_ctran} PARENT_SCOPE)

	ADD_CUSTOM_COMMAND (OUTPUT ${_ctran}
		COMMAND "${QT_LRELEASE_EXECUTABLE}" ${_tran}
		DEPENDS ${_tran}
		WORKING_DIRECTORY ${CMAKE_CURRENT_SOURCE_DIR}
		)
	INSTALL (FILES ${_ctran} DESTINATION ${LC_TRANSLATIONS_DEST})
	SET (${CompiledTranVar} ${_ctran} PARENT_SCOPE)
ENDFUNCTION (CreateTrs)

FUNCTION (CreateTrsUpTarget PlugName Langs Sources Forms Xml)
ENDFUNCTION (CreateTrsUpTarget)

SET (LC_PLUGINS_DEST lib/leechcraft/plugins)
SET (LC_TRANSLATIONS_DEST share/leechcraft/translations)
SET (LC_SETTINGS_DEST share/leechcraft/settings)
SET (LC_QML_DEST share/leechcraft/qml)
SET (LC_SHARE_DEST share/leechcraft)
SET (LC_INSTALLEDMANIFEST_DEST share/leechcraft/installed)

IF (UNIX)
	SET (CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -fvisibility=hidden -fno-strict-aliasing -std=c++0x")
ENDIF (UNIX)
